==> v8.3.zip: ru_twords_ru_tw/bible/other/seed.md <==
# семя, семена, зерно

## Определение:

Семя — это плод растения, который сажают в почву для того, чтобы выросло большое количество того же вида растения. Семя злаков называется зерном. Это слово может употребляться в переносном значении.

* В притче о сеятеле, Иисус сравнил семя с Божьим словом, насаждаемым в сердца людей и приносящим добрый духовный плод.
* Апостол Павел  использовал слово “семя” в значении “Божье Слово”
* Семенем называют мужские клетки, участвующие в оплодотворении.
* Семенем также называют потомство человека или животного. Члены какого-либо человеческого рода, происходящего от какого-либо прародителя, называются его семенем.

## Варианты перевода:

* Если речь идёт о семенах, которые сажают в почву, то лучше всего использовать слово, употребляющееся в целевом языке для обозначения этого понятия.
* Такое же слово следует использовать в контекстах, где речь идёт о Божьем Слове.
* В тех случаях, где это слово  употребляется для названия людей из одного рода, более точным переводом могут быть слова “потомок” или “потомство”, а не “семя”. Если целевом языке имеются отдельные слова для обозначения детей и внуков, следуе использовать их.
* Если речь идёт о семени мужчины, то переводите его таким словом, которое не оскорбит и не смутит читателя. (См.: [euphemism](rc://*/ta/man/translate/figs-euphemism))

(См. также: [потомок](../other/descendant.md), [отпрыск](../other/offspring.md))

## Ссылки на библейский текст:

* [3 Цар. 18:30-32](rc://*/tn/help/1ki/18/30)
* [Быт. 1:11-13](rc://*/tn/help/gen/01/11)
* [Иер. 2:20-22](rc://*/tn/help/jer/02/20)
* [Мф. 13:7-9](rc://*/tn/help/mat/13/07)

## Данные о слове:

* Номера Стронга: H2232, H2233, H2234, H3610, H6507, G4615, G4687, G4690, G4701, G4703

==> v9.2.zip: ru_twords_ru_tw/bible/other/seed.md <==
# семя, семена, зерно

## Определение:

Семя — это плод растения, который сажают в почву для того, чтобы выросло большое количество того же вида растения. Семя злаков называется зерном. Это слово может употребляться в переносном значении.
* В притче о сеятеле, Иисус сравнил семя с Божьим словом, насаждаемым в сердца людей и приносящим добрый духовный плод.
* Апостол Павел  использовал слово “семя” в значении “Божье Слово”
* Семенем называют мужские клетки, участвующие в оплодотворении.
* Семенем также называют потомство человека или животного. Члены какого-либо человеческого рода, происходящего от какого-либо прародителя, называются его семенем.

## Варианты перевода:

* Если речь идёт о семенах, которые сажают в почву, то лучше всего использовать слово, употребляющееся в целевом языке для обозначения этого понятия.
* Такое же слово следует использовать в контекстах, где речь идёт о Божьем Слове.
* В тех случаях, где это слово  употребляется для названия людей из одного рода, более точным переводом могут быть слова “потомок” или “потомство”, а не “семя”. Если целевом языке имеются отдельные слова для обозначения детей и внуков, следуе использовать их.
* Если речь идёт о семени мужчины, то переводите его таким словом, которое не оскорбит и не смутит читателя. (См.: [euphemism](rc://ru/ta/man/translate/figs-euphemism))

(См. также: [потомок](../other/descendant.md), [отпрыск](../other/offspring.md))

## Ссылки на библейский текст:

* [3 Цар. 18:30-32](rc://ru/tn/help/1ki/18/30)
* [Быт. 1:11-13](rc://ru/tn/help/gen/01/11)
* [Иер. 2:20-22](rc://ru/tn/help/jer/02/20)
* [Мф. 13:7-9](rc://ru/tn/help/mat/13/07)

## Данные о слове:

* Номера Стронга: H2232, H2233, H2234, H3610, H6507, G4615, G4687, G4690, G4701, G4703
